# Criticus
A suite of tools for transcribing, collating and and creating an apparatus criticus.

## install
Requires Python 3.8+

### Windows: 
- `pip install criticus`
- `python -m criticus`
### MacOS: 
- `pip3 install criticus`
- `python3 -m criticus`

Read the full [tutorial on GitHub](https://github.com/d-flood/criticus).
